# eric7.WebBrowser.SafeBrowsing.SafeBrowsingLabel

Module implementing the label to show some SSL info.

### Global Attributes

None

### Classes

SafeBrowsingLabel | Class implementing a label to show some Safe Browsing info.

### Functions

None

## SafeBrowsingLabel

Class implementing a label to show some Safe Browsing info.

### Signals

clicked(pos)
  emitted to indicate a click of the label (QPoint)

### Derived from

QLabel

### Class Attributes

nokStyle

### Class Methods

None

### Methods

SafeBrowsingLabel | Constructor
__updateLabel | Private slot to update the label text.
getThreatInfo | Public method to get the threat info text.
mouseDoubleClickEvent | Protected method to handle mouse double click events.
mouseReleaseEvent | Protected method to handle mouse release events.
setThreatInfo | Public slot to set threat information.

### Static Methods

None

#### SafeBrowsingLabel (Constructor)

SafeBrowsingLabel(parent=None)

Constructor

parent
  reference to the parent widget (QWidget)

#### SafeBrowsingLabel.__updateLabel

__updateLabel()

Private slot to update the label text.

#### SafeBrowsingLabel.getThreatInfo

getThreatInfo()

Public method to get the threat info text.

Return:
  threat info text

Return Type:
  str

#### SafeBrowsingLabel.mouseDoubleClickEvent

mouseDoubleClickEvent(evt)

Protected method to handle mouse double click events.

evt
  reference to the mouse event (QMouseEvent)

#### SafeBrowsingLabel.mouseReleaseEvent

mouseReleaseEvent(evt)

Protected method to handle mouse release events.

evt
  reference to the mouse event (QMouseEvent)

#### SafeBrowsingLabel.setThreatInfo

setThreatInfo(threatType, threatMessages)

Public slot to set threat information.

threatType (str)
  threat type
threatMessages (str)
  more verbose info about detected threats

Up